Module: GtfsReader::Version
- Defined in:
- lib/gtfs_reader/version.rb
Overview
This module both contains the current version of GtfsReader, but also has a Bumper class which will modify this file to increase the version
Defined Under Namespace
Classes: Bumper
Constant Summary collapse
- MAJOR =
The following four lines are generated, so don’t mess with them.
0- MINOR =
2- PATCH =
7- BUILD =
nil
Class Method Summary collapse
-
.to_s ⇒ String
The current version in the form of
1.2.3.build.
Class Method Details
.to_s ⇒ String
Returns the current version in the form of 1.2.3.build.
12 13 14 |
# File 'lib/gtfs_reader/version.rb', line 12 def self.to_s [MAJOR, MINOR, PATCH, BUILD].compact.join '.' end |